@@ -19,7 +19,7 @@ use constant {
 };
 
 BEGIN {
-	$VERSION = '1.0.0';
+	$VERSION = '1.0.1';
 	
 	require XSLoader;
 	XSLoader::load( __PACKAGE__, $VERSION );
@@ -142,7 +142,7 @@ __END__
 PAB3::DB::Driver::Mysql - Perl5 wrapper to the mysql5+ client libary and driver
 for the PAB3::DB class
 
-See more at L<PAB3::DB>
+See more at L<the PAB3::DB manpage|PAB3::DB>
 
 =head1 SYNOPSIS
 
@@ -268,7 +268,7 @@ If you plan using different connections in your scripts which may access to
 the same interpreter you should explicitly set I<$linkid> in all expected
 functions.
 You can alternatively use the C<PAB3::DB> class. It takes care of it by itself.
-See more at L<PAB3::DB>.
+See more at L<the PAB3::DB manpage|PAB3::DB>.
 
 =head2 Examples
 
@@ -394,7 +394,7 @@ B<Example>
 
 =item db_connect ( %arg )
 
-Wrapper to connect() used by L<PAB3::DB::connect()|PAB3::DB/item_connect>.
+Wrapper to connect() used by L<PAB3::DB::connect()|PAB3::DB/connect>.
 
 Following arguments are supported:
 
@@ -404,7 +404,7 @@ Following arguments are supported:
   db         => database name
   port       => port for tcp/ip connection
   socket     => unix socket for local connection
-  options    => hashref with parameters mapped to I<$client_flag>
+  options    => hashref with parameters mapped to $client_flag
                 these parameters are:
                 'reconnect', 'compress', 'interactive', 'ignore_space'
                 a description can be found at connect() above
@@ -424,8 +424,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -442,8 +442,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -461,8 +461,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$charset>
 
@@ -483,8 +483,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -502,8 +502,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -522,8 +522,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -547,8 +547,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$query>
 
@@ -575,8 +575,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$query>
 
@@ -605,7 +605,7 @@ B<Parameters>
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()>.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>.
 
 I<$p_num>
 
@@ -644,7 +644,7 @@ B<Parameters>
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()>.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>.
 
 I<@bind_values>
 
@@ -674,20 +674,23 @@ TRUE on success or FALSE on error.
 =item affected_rows ( $stmtid )
 
 Gets the number of affected rows in a previous SQL operation
-After executing a statement with L<query()> or L<execute()>, returns the number
+After executing a statement with L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>, returns the number
 of rows changed (for UPDATE), deleted (for DELETE), or inserted (for INSERT).
-For SELECT statements, affected_rows() works like L<num_rows()>. 
+For SELECT statements, affected_rows() works like
+L<num_rows()|PAB3::DB::Driver::Mysql/num_rows>. 
 
 B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()>.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -709,12 +712,13 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()>.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -743,11 +747,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -765,11 +771,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -780,7 +788,7 @@ result set's columns or NULL if there are no more rows in resultset.
 If two or more columns of the result have the same field names, the last
 column will take precedence. To access the other column(s) of the same name,
 you either need to access the result with numeric indices by using
-L<fetch_row()> or add alias names.
+L<fetch_row()|PAB3::DB::Driver::Mysql/fetch_row> or add alias names.
 
 
 =item fetch_col ( $resid )
@@ -793,11 +801,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -815,11 +825,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -837,11 +849,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -858,11 +872,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -879,15 +895,18 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 I<$offset>
 
-Absolute row position. Valid between 0 and L<num_rows()> - 1.
+Absolute row position. Valid between 0 and
+L<num_rows()|PAB3::DB::Driver::Mysql/num_rows> - 1.
 
 B<Return Values>
 
@@ -910,11 +929,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -931,11 +952,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -956,11 +979,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 I<$offset>
 
@@ -982,11 +1007,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -1003,15 +1030,18 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 I<$offset>
 
-Absolute field position. Valid between 0 and L<num_fields()> - 1.
+Absolute field position. Valid between 0 and
+L<num_fields()|PAB3::DB::Driver::Mysql/num_fields> - 1.
 
 B<Return Values>
 
@@ -1034,11 +1064,13 @@ B<Paramters>
 
 I<$resid>
 
-A result set identifier returned by L<query()> or L<execute()>.
+A result set identifier returned by L<query()|PAB3::DB::Driver::Mysql/query> or
+L<execute()|PAB3::DB::Driver::Mysql/execute>.
 
 I<$stmtid>
 
-A statement identifier returned by L<prepare()> which has been executed.
+A statement identifier returned by L<prepare()|PAB3::DB::Driver::Mysql/prepare>
+which has been executed.
 
 B<Return Values>
 
@@ -1063,8 +1095,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$mode>
 
@@ -1086,8 +1118,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -1104,8 +1136,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -1122,8 +1154,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 B<Return Values>
 
@@ -1198,8 +1230,8 @@ B<Parameters>
 
 I<$linkid>
 
-A link identifier returned by L<connect()>. If the link identifier is not
-specified, the last link is assumed.
+A link identifier returned by L<connect()|PAB3::DB::Driver::Mysql/connect>.
+If the link identifier is not specified, the last link is assumed.
 
 I<$value>
 
